@@ -4,11 +4,12 @@ use warnings;
 
 use version;
 
+use Carp qw(croak);
 use Data::Dumper;
 use Test::BrewBuild::Constant qw(:all);
 use Test::BrewBuild::Regex;
 
-our $VERSION = '2.20';
+our $VERSION = '2.21';
 
 my $log;
 
@@ -62,6 +63,10 @@ sub info {
 sub installed {
     my ($self, $legacy, $info) = @_;
 
+    if (! defined $legacy || ($legacy !~ /^[01]$/)){
+        croak "'legacy' param must be included, and must be either 0 or 1\n";
+    }
+
     $log->child('installed')->_6("cleaning up perls installed");
 
     return if ! $info;
